# PyLibreHardwareMonitorLib

This is a repository of LibreHardwareMonitorLib.dll files from various releases of [LibreHardwareMonitorLib](https://github.com/LibreHardwareMonitor/LibreHardwareMonitor) for use in the [PyLibreHardwareMonitor](https://github.com/EVA-JianJun/PyLibreHardwareMonitor) project.

这是 [LibreHardwareMonitorLib](https://github.com/LibreHardwareMonitor/LibreHardwareMonitor) 的各个 releases 版本的 LibreHardwareMonitorLib.dll 文件库, 供 [PyLibreHardwareMonitor](https://github.com/EVA-JianJun/PyLibreHardwareMonitor) 项目使用.
